parade package
==============

Subpackages
-----------

.. toctree::

    parade.api
    parade.command
    parade.config
    parade.connection
    parade.core
    parade.error
    parade.flowrunner
    parade.flowstore
    parade.notify
    parade.type

Submodules
----------

parade.cmdline module
---------------------

.. automodule:: parade.cmdline
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: parade
    :members:
    :undoc-members:
    :show-inheritance:
